@@ -206,7 +206,7 @@ class commandServer(color_print):
             errMessage = _("Wrong password")
             return False, errMessage
         except ldap.LDAPError as e:
-            errMessage = e[0]['desc']
+            errMessage = e.args[0]['desc']
             return False, errMessage
         return True, errMessage
 
@@ -1335,7 +1335,7 @@ class Client(commandServer, encrypt, Desktop):
         if not self.syncUserNew(ps, uid, gid, homeDir, "login",
                                 remoteProfile, host=host,
                                 rsyncopts=remoteOpts):
-            error_output = ps.output
+            error_output = ps.output.decode("UTF-8")
             if remoteOpts and re.search(r"(on remote machine.*unknown option|"
                           "unknown compress name:)",
                     error_output):
@@ -1373,7 +1373,7 @@ class Client(commandServer, encrypt, Desktop):
                 f.write("SUCCESS")
             if not self.syncUserNew(ps, uid, gid, homeDir, "logout",
                                     remoteProfile, host=host, skipList=skipList):
-                self.printERROR(ps.output)
+                self.printERROR(ps.output.decode("UTF-8"))
                 self.printERROR(_("Failed to execute rsync"))
                 return False
         return True
